Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(344)

Unified Diff: content/browser/mojo/constants.cc

Issue 2099423002: Convert UtilityProcess to use MojoChild/ShellConnection for the shell handshake. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@gpu
Patch Set: . Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/browser/mojo/constants.h ('k') | content/browser/mojo/mojo_child_connection.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/browser/mojo/constants.cc
diff --git a/content/browser/mojo/constants.cc b/content/browser/mojo/constants.cc
index d13cdb82a832e71f8798de7727727540cbc30bc1..4fe5f2ab7051a15b2297dd1e3b91f9d1bcb8a844 100644
--- a/content/browser/mojo/constants.cc
+++ b/content/browser/mojo/constants.cc
@@ -11,14 +11,19 @@ namespace content {
// src/content/public/app/mojo/content_browser_manifest.json.
const char kBrowserMojoApplicationName[] = "exe:content_browser";
+// The default application name used to identify the gpu process when
+// connecting it to the shell. This must match the name in
+// src/content/public/app/mojo/content_gpu_manifest.json.
+const char kGpuMojoApplicationName[] = "exe:content_gpu";
+
// The default application name used to identify render processes when
// connecting them to the shell. This must match the name in
// src/content/public/app/mojo/content_renderer_manifest.json.
const char kRendererMojoApplicationName[] = "exe:content_renderer";
-// The default application name used to identify the gpu process when
-// connecting it to the shell. This must match the name in
-// src/content/public/app/mojo/content_gpu_manifest.json.
-const char kGpuMojoApplicationName[] = "exe:content_gpu";
+// The default application name used to identify utility processes when
+// connecting them to the shell. This must match the name in
+// src/content/public/app/mojo/content_utility_manifest.json.
+const char kUtilityMojoApplicationName[] = "exe:content_utility";
} // namespace content
« no previous file with comments | « content/browser/mojo/constants.h ('k') | content/browser/mojo/mojo_child_connection.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698